CKAN: The Open Source Data Portal Software
==========================================

.. image:: https://secure.travis-ci.org/okfn/ckan.png?branch=master
    :target: http://travis-ci.org/okfn/ckan
    :alt: Build Status

**CKAN is the world’s leading open-source data portal platform**.
CKAN makes it easy to publish, share and work with data. It's a data management
system that provides a powerful platform for cataloging, storing and accessing
datasets with a rich front-end, full API (for both data and catalog), visualization
tools and more. Read more at `ckan.org <http://ckan.org/>`_. 


Installation
------------

See the `CKAN Documentation <http://docs.ckan.org>`_ for installation instructions.


Community
---------

* Developer mailing list: `ckan-dev@lists.okfn.org <http://lists.okfn.org/mailman/listinfo/ckan-dev>`_
* Developer IRC channel: `#ckan on irc.freenode.net <http://webchat.freenode.net/?channels=ckan>`_
* `Issue tracker <https://github.com/okfn/ckan/issues>`_
* `CKAN tag on StackOverflow <http://stackoverflow.com/questions/tagged/ckan>`_
* `Wiki <https://github.com/okfn/ckan/wiki>`_


Contributing to CKAN
--------------------

For contributing to CKAN or its documentation, see
`CONTRIBUTING <https://github.com/okfn/ckan/blob/master/CONTRIBUTING.rst>`_.


Copying and License
-------------------

This material is copyright (c) 2006-2011 Open Knowledge Foundation.

It is open and licensed under the GNU Affero General Public License (AGPL) v3.0
whose full text may be found at:

http://www.fsf.org/licensing/licenses/agpl-3.0.html
